pub struct ObjectConfig<'a, T: DriverObject> {
pub map_wc: bool,
pub parent_resv_obj: Option<&'a Object<T>>,
}Expand description
A struct for controlling the creation of shmem-backed GEM objects.
This is used with Object::new() to control various properties that can only be set when
initially creating a shmem-backed GEM object.
Fields
map_wc: boolWhether to set the write-combine map flag.
parent_resv_obj: Option<&'a Object<T>>Reuse the DMA reservation from another GEM object.
The newly created Object will hold an owned refcount to parent_resv_obj if specified.