VMap

Struct VMap 

pub struct VMap<D, R, C = Registered, const SIZE: usize = 0>
where D: DriverObject, C: DeviceContext, R: Deref<Target = Object<D, C>>,
{ /* private fields */ }
A reference to a virtual mapping for an shmem-based GEM object in kernel address space.

Invariants

  • The size of owner is >= SIZE.
  • The memory pointed to by addr remains valid at least until this object is dropped.

Implementations

Source

impl<D, R, C, const SIZE: usize> VMap<D, R, C, SIZE>
where D: DriverObject, C: DeviceContext, R: Deref<Target = Object<D, C>>,

pub fn owner(&self) -> &Object<D, C>

Borrows a reference to the object that owns this virtual mapping.